astrodendro.pruning
====================

.. currentmodule:: astrodendro.pruning

.. automodule:: astrodendro.pruning

.. autofunction:: min_delta

.. autofunction:: min_sum

.. autofunction:: min_peak

.. autofunction:: min_npix

.. autofunction:: contains_seeds

.. autofunction:: all_true
